# Motion Graphics Components

Reusable animated overlay clips for video production.

## LowerThird

::: pymotion.clip.motion_graphics.LowerThird

## LogoReveal

::: pymotion.clip.motion_graphics.LogoReveal

## CallToAction

::: pymotion.clip.motion_graphics.CallToAction

## SocialHandle

::: pymotion.clip.motion_graphics.SocialHandle

## Countdown

::: pymotion.clip.motion_graphics.Countdown

## QuoteCard

::: pymotion.clip.motion_graphics.QuoteCard

## Divider

::: pymotion.clip.motion_graphics.Divider

## TransitionTitle

::: pymotion.clip.motion_graphics.TransitionTitle

## Watermark

::: pymotion.clip.motion_graphics.Watermark
